import base64
import string
from .exceptions import *
from .enums import Algorithms
import enum

def xor(string,key=0):
    if type(string) == str:
        string = bytes(string,encoding='utf-8')
    elif type(string) == bytes:
        pass
    else:
        raise TypeError("Type Should Be 'str' Or 'bytes'.")
    if type(key) == int:
        ans = ""
        for i in string:
            ans += chr(i ^ key)
    else:
        raise TypeError("key Type Must Be Int.")
    return ans

def b64_en(string):
    if type(string) == str:
        string = bytes(string,encoding='utf-8')
    elif type(string) == bytes:
        pass
    else:
        raise TypeError("Type Should Be 'str' Or 'bytes'.")
    return base64.b64encode(string).decode('utf-8')

def b64_de(string):
    if type(string) == str:
        string = bytes(string,encoding='utf-8')
    elif type(string) == bytes:
        pass
    else:
        raise TypeError("Type Should Be 'str' Or 'bytes'.")
    return base64.b64decode(string).decode('utf-8')

def cipher_en(s,key=1):
    if type(key) == str:
        try:
            key = int(key)
        except:
            raise TypeError("Type Should Be 'int'.")
    elif type(key) == int:
        pass
    else:
        raise TypeError("Type Should Be 'int'.")
    
    slow = string.ascii_lowercase + string.ascii_lowercase
    sup = string.ascii_uppercase + string.ascii_uppercase

    ans = ""

    for i in s:
        if i in string.ascii_lowercase:
            ans += slow[slow.index(i) + key]
        elif i in string.ascii_uppercase:
            ans += sup[sup.index(i) + key]
        else:
            ans += i
    
    return ans

def cipher_de(s,key=1):
    if type(key) == str:
        try:
            key = int(key)
        except:
            raise TypeError("Type Should Be 'int'.")
    elif type(key) == int:
        pass
    else:
        raise TypeError("Type Should Be 'int'.")
    
    slow = string.ascii_lowercase + string.ascii_lowercase
    sup = string.ascii_uppercase + string.ascii_uppercase

    ans = ""

    for i in s:
        if i in string.ascii_lowercase:
            ans += slow[slow.index(i) - key]
        elif i in string.ascii_uppercase:
            ans += sup[sup.index(i) - key]
        else:
            ans += i
    
    return ans

def make_enc(alg,key=b""):
    if str(type(alg)) == "<enum 'Algorithms'>":
        print(alg,type(alg))
        if alg.name == Algorithms.XOR.name:
            return lambda s:xor(s,key)
        elif alg.name == Algorithms.Base64.name:
            return [lambda s:b64_en(s),lambda s:b64_de(s)]
        elif alg.name == Algorithms.Cipher.name:
            return [lambda s:cipher_en(s,key),lambda s:cipher_de(s,key)]
        else:
            raise AlgorithmError(f"This Algorithm Is Not Available. We Will Be Happy If You Help Us To Make It :)\nGithub : https://github.com/Arshiatmi/Pysha")
    elif type(alg) == list or type(alg) == set:
        for i in alg:
            if type(i) == enum.EnumMeta:
                pass
            else:
                raise AlgorithmError(f"Type {i} Is Not Supported. Just (Algorithms.Base64/Algorithms.XOR/Algorithms.Cypher) Is Supported.")
        pass
    else:
        raise AlgorithmError(f"This Type Of Algorithm Is Not Supported. Just enum.EnumMeta (Algorithms.Base64/...),list and set Are Supported.")



from .exceptions import *

class Stack:
    def __init__(self,inf=1,capacity=0):
        self.inf = inf
        if inf:
            self.__storage = []
        else:
            self.ind = 0
            self.__storage = [0 for _ in range(capacity)]
            self.capacity = capacity
    
    @property
    def storage(self):
        return self.__storage
    
    def push(self,elem):
        if self.inf:
            self.__storage.append(elem)
        else:
            if self.ind == self.capacity:
                raise StackError("Stack Is Full !")
            self.__storage[self.ind] = elem
            self.ind += 1
    
    def pop(self):
        if self.__storage:
            self.__storage.pop()
        else:
            raise StackError("Stack Is Empty !")
    
    def display(self):
        return self.storage

class LIFO(Stack):
    pass

class Queue:
    def __init__(self,inf=1,capacity=0):
        self.inf = inf
        if inf:
            self.__storage = []
        else:
            self.ind = 0
            self.__storage = [0 for _ in range(capacity)]
            self.capacity = capacity
    
    @property
    def storage(self):
        return self.__storage
    
    def add(self,elem):
        if self.inf:
            self.__storage.append(elem)
        else:
            if self.ind == self.capacity:
                raise QueueError("Queue Is Full !")
            self.__storage[self.ind] = elem
            self.ind += 1
    
    def remove(self):
        if self.__storage:
            self.__storage.pop(0)
        else:
            raise QueueError("Queue Is Empty !")
    
    def display(self):
        return self.storage


class FIFO(Queue):
    pass


from .functions import *
from os import environ, popen, remove

class command:
    def __init__(self):
        self.arr_data = []
        self.dic_tar = {}
        self._mode = 'p'
    
    @property
    def mode(self):
        return self._mode
    
    @mode.setter
    def mode(self,m):
        if m not in ['p','i']:
            raise ModeError("Modes Should Be 'p' Or 'i'. Default Is 'p' / Print Mode.")
        else:
            self._mode = m

    """
    2 Types Of Loop Currently Exists. i(Input) and p(Print) Mode.
    In print mode you can make a print loop like that :
        <i:3>{You Are In _i_ Loop}
    And This Will Be Printed Like That : 
        You Are In 0 Loop
        You Are In 1 Loop
        You Are In 2 Loop

    And In Input Mode You Can Do This :
        <i:3>{Enter _i_ Number : }
    It Will Get 3 Input Like This :
        Enter 0 Number : (input0)
        Enter 1 Number : (input1)
        Enter 2 Number : (input2)
    And Will Return [input0,input1,input2]

    More Options :
        <i:3>{Enter _i++_ Number : }
        <i:3>{Enter _i--_ Number : }
        <i:2,j:2>{Enter Row _i++_ And Column _j++_  Number : }
        <i:2>{Enter (Fore.CYAN)[_i++_] Number : }
    
    Notes :
        Just Maded Maximum For 2 Variables Not More.
    """
    def loop(self,cmd,mode='p',c=True):
        if self.mode != 'p':
            mode = self.mode
        if mode == "p": # Print Mode
            self.dic_tar.clear()
            self.arr_data.clear()
            alls = cmd.split(">")[0][1:]
            string = cmd.split("{")[1][:-1]
            for i in alls.split(','):
                itemp = i.split(':')
                self.arr_data.append(itemp[0].strip())
                self.dic_tar[itemp[0].strip()] = int(itemp[1].strip())
            if len(self.dic_tar.keys()) >= 3:
                raise LoopError("Loops With 3 Or More Variables Are Not Supported In This Version.")
            tars = make_possibles(self.dic_tar)
            for i in tars:
                temp = {}
                if not (type(i) == int) and len(i) == 2:
                    temp = {self.arr_data[0]:i[0],self.arr_data[1]:i[1]}
                else:
                    temp = {self.arr_data[0]:i}
                display(temp,string,c)
        elif mode == 'i': #input Mode
            self.dic_tar.clear()
            self.arr_data.clear()
            alls = cmd.split(">")[0][1:]
            string = cmd.split("{")[1][:-1]
            for i in alls.split(','):
                itemp = i.split(':')
                self.arr_data.append(itemp[0].strip())
                self.dic_tar[itemp[0].strip()] = int(itemp[1].strip())
            if len(self.dic_tar.keys()) >= 3:
                raise LoopError("Loops With 3 Or More Variables Are Not Supported In This Version.")
            tars = make_possibles(self.dic_tar)
            x = 0
            y = 0
            ls = []
            if len(self.dic_tar) == 2:
                x = (list(self.dic_tar.values())[0])
                y = (list(self.dic_tar.values())[1])
                ls = [["" for _ in range(y)] for __ in range(x)]
            elif len(self.dic_tar) == 1:
                x = (list(self.dic_tar.values())[0])
                ls = ["" for _ in range(x)]
            x = 0
            y = 0
            for i in tars:
                temp = {}
                if not (type(i) == int) and len(i) == 2:
                    temp = {self.arr_data[0]:i[0],self.arr_data[1]:i[1]}
                    try:
                        ls[x][y] = get_ans(temp,string,c)
                        ls[x][y + 1]
                        y += 1
                    except:
                        try:
                            ls[x + 1][y]
                            x += 1
                            y = 0
                        except:
                            pass
                else:
                    temp = {self.arr_data[0]:i}
                    try:
                        ls[x] = get_ans(temp,string,c)
                        ls[x]
                        x += 1
                    except:
                        pass
                
            return ls
        else:
            raise ValueError("Mode Should Be 'p' Or 'i' !")
    

    """
    This Function Act As c++ One Line Condition.
    You Can Use This Function Like :
        condition("i > j ? 'i Is Grater' : 'j Is Grater'",i=20,j=23)
    Output Will Be :
        "j Is Grater"
    """
    def condition(self,check,p=True,**kwargs):
        if not re.match("""(\'?|\"?)[ -~]+(\'?|\"?)(>|<|==|>=|<=)(\'?|\"?)[ -~]+(\'?|\"?)\?(\'?|\"?)[ -~]+(\'?|\"?):(\'?|\"?)[ -~]+(\'?|\"?)""",''.join(check.split(' '))):
            raise ConditionError("An Error In Parsing Condition :(")
        if "eval" in check:
            if not check[check.find("eval") - 1:].startswith("\eval"):
                raise SecurityError("Using This Funcion Is Forbidden.")
        if "exec" in check:
            if not check[check.find("exec") - 1:].startswith("\exec"):
                raise SecurityError("Using This Funcion Is Forbidden.")
        p1 = check.split("?")[0].strip()
        p2 = check.split("?")[1].strip()
        ans = eval(p1,kwargs,{})
        ok = p2.split(':')[0].strip()
        not_ok = p2.split(':')[1].strip()
        if ans:
            if p:
                print(eval(ok,kwargs,{}))
            else:
                return eval(ok,kwargs,{})
        else:
            if p:
                print(eval(not_ok,kwargs,{}))
            else:
                return eval(not_ok,kwargs,{})
    
    """

    """
    def exe(self,string,priority=0,strip_response=True):
        s = re.compile("\$\([A-Za-z0-9_ \$\&\!\@\#\%\^\*\+\=\-\]\[\~\?\'\"\;\:]+\)")
        p = re.compile("\#\([A-Za-z0-9_ \$\&\!\@\#\%\^\*\+\=\-\]\[\~\?\'\"\;\:]+\)")
        if priority == 0:
            # First System Then Python
            for cmd in s.finditer(string):
                cmds = cmd.group()[2:-1]
                ans = popen(cmds).read()
                string = string[:cmd.start()] + ans + string[cmd.start() + len(cmd.group()):]
            for cmd in p.finditer(string):
                cmds = cmd.group()[2:-1]
                f = open("temp.py","w")
                f.write(cmds)
                f.close()
                print("=" * 80)
                print("Got Here")
                print("=" * 80)
                ans = popen(environ.get("python") + " temp.py").read()
                print("=" * 80)
                print("Got Here Too")
                print("=" * 80)
                print("answer - > ",ans)
                pdb.set_trace()
                remove("temp.py")
                string = string[:cmd.start()] + ans + string[cmd.start() + len(cmd.group()):]
            if strip_response:
                return string.strip()
            else:
                return string
        elif priority == 1:
            # First Python Then System
            for cmd in p.finditer(string):
                cmds = cmd.group()[2:-1]
                f = open("temp.py","w")
                f.write(cmds)
                f.close()
                ans = popen(environ.get("python") + " temp.py").read()
                print("answer - > ",ans)
                pdb.set_trace()
                remove("temp.py")
                string = string[:cmd.start()] + ans + string[cmd.start() + len(cmd.group()):]
            for cmd in s.finditer(string):
                cmds = cmd.group()[2:-1]
                ans = popen(cmds).read()
                string = string[:cmd.start()] + ans + string[cmd.start() + len(cmd.group()):]
            if strip_response:
                return string.strip()
            else:
                return string
        else:
            ValueError("Priority Should Be 0 (System First) Or 1 (Python First).")

class Switch:
    def __init__(self,var):
        self.var = var
    
    def case(self,tar,func,args=tuple()):
        if self.var == tar:
            func(*args)
    
    def cases(self,all_funcs):
        for i,j in all_funcs.items():
            if self.var == i or (hasattr(i,'__name__') and i.__name__ == "Case" and i.tar == self.var) or (hasattr(i,'__name__') and i.__name__ == "Default"):
                if hasattr(j,'__call__'):
                    j()
                    return
                elif type(j) == str:
                    parts = j.split('\n')
                    if parts[0].strip():
                        t = parts[0].index(j.split('\n')[0].strip())
                    else:
                        t = parts[1].index(j.split('\n')[1].strip())
                    ok_code = ""
                    for i in j.split('\n'):
                        ok_code += i[t:] + "\n"
                    b = compile(ok_code,'user_code','exec')
                    a = exec(b)
                    if a != None:
                        print(a)
                if len(j) == 3:
                    j[0](*j[1],**j[2])
                elif len(j) == 2:
                    j[0](*j[1])
                elif len(j) == 1:
                    j[0]()

class Default:
    pass

class Case:
    def __init__(self,tar):
        self.tar = tar

class Vars:
    pass

class PercentPrinter:
    def __init__(self,chars=100,pass_color=fore["reset"],loading_color=fore["reset"]):
        self._percent = 0
        self.chars = chars
        self.pass_color=pass_color
        self.loading_color=loading_color
    
    def show(self,char_ok='#',char_loading='-',end='\n'):
        num = self._percent
        string = "\r"
        string += (self.pass_color + char_ok + Fore.RESET) * int(num * (self.chars / 100))
        string += (self.loading_color + char_loading + Fore.RESET) * int((100 - num) * (self.chars / 100))
        print(string,end=end)
    
    @property
    def percent(self):
        return self._percent
    
    @percent.setter
    def percent(self,p):
        if p > 100:
            raise ValueError("Value Most Be Less Than 100 !")
        elif p < 0:
            raise ValueError("Value Most Be More Than 0 !")
        else:
            self._percent = p
    
    def increase(self,p=1):
        self._percent += p
        
    def finish(self):
        self._percent = 100


from typing import Union
from os import popen,mkdir,makedirs,rmdir
from shutil import rmtree
from .colors import *
from .exceptions import *
import re
import readchar,sys
from .security import *


"""
This Will Act Like Input. But Characters That User Enters Will Be Colored :)
Args :
    prompt      ->   The Text For Print And Wait For Input.
    
    out         ->   Just Standard Output. DO NOT TOUCH THIS :/

    char_color  ->   The Color Of Character. Each Character Will Have This 
                     Color.

"""
def colorprompt(prompt: str,out = sys.stdout,char_color=fore["reset"]):
    out.write(prompt); out.flush()
    password = ""
    while True:
        ch = str(readchar.readchar(), encoding='UTF-8')
        if ch == '\r':
            break
        elif ch == '\b':
            out.write('\b \b')
            password = password[0:len(password)-1]
            out.flush()
        else: 
            password += ch
            out.write(char_color + ch + fore["reset"])
            out.flush()
    print()
    return password


"""
This Will Get Password And Replace Characters With A Mask For Example '*'.
Args :
    prompt      ->   The Text For Print And Wait For Input.

    out         ->   Just Standard Output. DO NOT TOUCH THIS :/

    mask_color  ->   The Color Of Mask. For Example You Can Print Red Stars For
                     Each Character :))

    mask        ->   The Mask. Every Character That User Type, Will Be Replaced With
                     This Character :)
"""
def passprompt(prompt: str, out = sys.stdout,mask_color=fore["reset"],mask='*') -> str:
    out.write(prompt); out.flush()
    password = ""
    while True:
        ch = str(readchar.readchar(), encoding='UTF-8')
        if ch == '\r':
            break
        elif ch == '\b':
            out.write('\b \b')
            password = password[0:len(password)-1]
            out.flush()
        else: 
            password += ch
            out.write(mask_color + mask + fore["reset"])
            out.flush()
    print()
    return password

"""
It Will Colorize The Input.
Example :
    colorize("(Fore.GREEN)[Hello !]")
Output :
    Green Foreground -> |Hello !|

Possible Colors:
    fore = {
        "green" : Fore.GREEN,
        "black":Fore.BLACK,
        "red":Fore.RED,
        "yellow":Fore.YELLOW,
        "blue":Fore.BLUE,
        "cyan":Fore.CYAN,
        "light_black":Fore.LIGHTBLACK_EX,
        "light_blue":Fore.LIGHTBLUE_EX,
        "light_cyan":Fore.LIGHTCYAN_EX,
        "light_green":Fore.LIGHTGREEN_EX,
        "light_magenta":Fore.LIGHTMAGENTA_EX,
        "light_red":Fore.LIGHTRED_EX,
        "light_white":Fore.LIGHTWHITE_EX,
        "light_yellow":Fore.LIGHTYELLOW_EX,
        "magenta":Fore.MAGENTA,
        "reset":Fore.RESET,
        "white":Fore.WHITE
    }

    back = {
        "green":Back.GREEN,
        "black":Back.BLACK,
        "red":Back.RED,
        "yellow":Back.YELLOW,
        "blue":Back.BLUE,
        "cyan":Back.CYAN,
        "light_black":Back.LIGHTBLACK_EX,
        "light_blue":Back.LIGHTBLUE_EX,
        "light_cyan":Back.LIGHTCYAN_EX,
        "light_green":Back.LIGHTGREEN_EX,
        "light_magenta":Back.LIGHTMAGENTA_EX,
        "light_red":Back.LIGHTRED_EX,
        "light_white":Back.LIGHTWHITE_EX,
        "light_yellow":Back.LIGHTYELLOW_EX,
        "magenta":Back.MAGENTA,
        "reset":Back.RESET,
        "white":Back.WHITE
    }

    You Can Always Access The Colors Like That :
        pysha.fore[...]
        pysha.back[...]
"""
def colorize(string: str) -> str:
    data = re.findall("\(Back|\(Fore\.[A-Z]*\)\[[a-zA-Z0-9_ :\/\\\'\"\+\=\-\$\%\^\&\*\@\!\#\(\)\?]*\]",string)
    for i in data:
        tp = i.split('.')[0][1:].strip()
        colr = i.split('.')[1].split(')')[0].strip()
        text = '['.join(i.split('[')[1:])[:-1]
        if tp.lower() == "fore":
            c = getattr(Fore,colr)
            string = string.replace(i,c + text + Fore.RESET)
        elif tp.lower() == "back":
            c = getattr(Back,colr)
            string = string.replace(i,c + text + Back.RESET)
        else:
            raise TypeError("Type Must Be Back Or Fore.")
    return string

"""
Tries To Get Possible Situations Of For Loops ( Max 2 Variable ).
"""
def make_possibles(data):
    if len(data.keys()) == 1:
        return list(range(list(data.values())[0]))
    else:
        l1 = list([[i] for i in range(list(data.items())[0][1])])
        ans = []
        for i in l1:
            temp = []
            for key,value in list(data.items())[1:]:
                for j in range(value):
                    temp.append(i + [j])
            ans.extend(temp)
        return ans

"""
Related To Loop Command. It Will Print String And Replace _i_ , _i++_ ... With The Value.
    Args :
        temp    ->     Carries Variables.
        string  ->     The String Pattern That Should Be Printed In Output.
        c       ->     If Its True, Answer Will colorized. And Else Won't Be Colorized.
"""
def display(temp: dict,string: str,c=True) -> None:
    ans = string
    for i,j in temp.items():
        ans = (ans.replace(f"_{i}_",str(j)).replace(f"_{i}++_",str(j+1)).replace(f"_{i}--_",str(j-1)))
    if not c:
        print(ans)
    else:
        print(colorize(ans))

"""
Related To Loop Command. It Will Get Input And Replace _i_ , _i++_ ... With The Value.
    Args :
        temp    ->     Carries Variables.
        string  ->     The String Pattern That Should Be Printed In Output.
        c       ->     If Its True, Answer Will colorized. And Else Won't Be Colorized.
"""
def get_ans(temp: dict,string: str,c=True) -> str:
    ans = string
    for i,j in temp.items():
        ans = (ans.replace(f"_{i}_",str(j)).replace(f"_{i}++_",str(j+1)).replace(f"_{i}--_",str(j-1)))
    if not c:
        return input(ans)
    else:
        return input(colorize(ans))


"""
All Descriptions From This Function Came In `classes.py` - command Class.
"""
def loop(cmd: str,mode='p',c=True) -> Union[None,str]:
    if mode == "p": # Print Mode
        alls = cmd.split(">")[0][1:]
        string = cmd.split("{")[1][:-1]
        arr_data = []
        dic_tar = {}
        for i in alls.split(','):
            itemp = i.split(':')
            arr_data.append(itemp[0].strip())
            dic_tar[itemp[0].strip()] = int(itemp[1].strip())
        if len(dic_tar.keys()) >= 3:
            raise LoopError("Loops With 3 Or More Variables Are Not Supported In This Version.")
        tars = make_possibles(dic_tar)
        for i in tars:
            temp = {}
            if not (type(i) == int) and len(i) == 2:
                temp = {arr_data[0]:i[0],arr_data[1]:i[1]}
            else:
                temp = {arr_data[0]:i[0]}
            display(temp,string,c)
    elif mode == 'i': #input Mode
        alls = cmd.split(">")[0][1:]
        string = cmd.split("{")[1][:-1]
        arr_data = []
        dic_tar = {}
        for i in alls.split(','):
            itemp = i.split(':')
            arr_data.append(itemp[0].strip())
            dic_tar[itemp[0].strip()] = int(itemp[1].strip())
        if len(dic_tar.keys()) >= 3:
            raise LoopError("Loops With 3 Or More Variables Are Not Supported In This Version.")
        tars = make_possibles(dic_tar)
        x = 0
        y = 0
        ls = []
        if len(dic_tar) == 2:
            x = (list(dic_tar.values())[0])
            y = (list(dic_tar.values())[1])
            ls = [["" for _ in range(y)] for __ in range(x)]
        elif len(dic_tar) == 1:
            x = (list(dic_tar.values())[0])
            ls = ["" for _ in range(x)]
        x = 0
        y = 0
        for i in tars:
            temp = {}
            if not (type(i) == int) and len(i) == 2:
                temp = {arr_data[0]:i[0],arr_data[1]:i[1]}
            else:
                temp = {arr_data[0]:i}
            try:
                ls[x][y] = get_ans(temp,string,c)
                ls[x][y + 1]
                y += 1
            except:
                try:
                    ls[x + 1][y]
                    x += 1
                    y = 0
                except:
                    pass
        return ls
    else:
        raise ModeError("Mode Should Be 'p' Or 'i' !")


"""
Descrioptions Are Available In 'classes.py' And In command Class.
"""
def condition(check : str,p=True,**kwargs) -> Union[None,str,int]:
    if not re.match("""(\'?|\"?)[ -~]+(\'?|\"?)(>|<|==|>=|<=)(\'?|\"?)[ -~]+(\'?|\"?)\?(\'?|\"?)[ -~]+(\'?|\"?):(\'?|\"?)[ -~]+(\'?|\"?)""",''.join(check.split(' '))):
        raise ConditionError("An Error In Parsing Condition :(")
    p1 = check.split("?")[0].strip()
    p2 = check.split("?")[1].strip()
    ans = eval(p1,kwargs)
    ok = p2.split(':')[0].strip()
    not_ok = p2.split(':')[1].strip()
    if ans:
        if p:
            print(eval(ok,kwargs))
        else:
            return eval(ok,kwargs)
    else:
        if p:
            print(eval(not_ok,kwargs))
        else:
            return eval(not_ok,kwargs)

def _(cmd):
    return popen(cmd).read()

def write_file(file_name: str,text : Union[str,list]) -> bool:
    if type(text) == str:
        try:
            a = open(file_name,"w")
            a.write(text)
            a.close()
            return True
        except:
            return False
    elif type(text) == list:
        try:
            a = open(file_name,"w")
            a.writelines(text)
            a.close()
            return True
        except:
            return False

def read_file(file_name: str,mode="s") -> Union[list,str]:
    try:
        a = open(file_name,"r")
        d = a.readlines()
        a.close()
        if mode == "s":
            return "".join(d)
        elif mode == "l":
            return d
        else:
            raise ModeError(f"Mode {mode} Not Found ! Mode Should Be 's'(string) Or 'l'(List)")
    except:
        return ""


def append_file(file_name: str,text: str) -> bool:
    if type(text) == str:
        try:
            a = open(file_name,"a")
            a.write(text)
            a.close()
            return True
        except:
            return False
    elif type(text) == list:
        try:
            a = open(file_name,"a")
            a.writelines(text)
            a.close()
            return True
        except:
            return False

def create_dir(dir_name: str,create_parents=False) -> bool:
    if create_parents:
        try:
            makedirs(dir_name)
            return True
        except:
            return False
    else:
        try:
            mkdir(dir_name)
            return True
        except:
            return False


def rm_dir(dir_name: str,force=False) -> bool:
    if not force:
        try:
            rmdir(dir_name)
            return True
        except:
            return False
    else:
        try:
            rmtree(dir_name)
            return True
        except:
            return False




import setuptools


setuptools.setup(
    name="pysha",
    version="0.0.1.2.1",
    author="Arshiatmi",
    author_email="1arhacker1@gmail.com",
    description="A New Python Micro Framework",
    long_description_content_type="text/markdown",
    url="https://github.com/Arshiatmi/Pysha",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)